@@ -1,6 +1,6 @@
 package Net::ZooKeeper::Lock;
-BEGIN {
-  $Net::ZooKeeper::Lock::VERSION = '0.02';
+{
+  $Net::ZooKeeper::Lock::VERSION = '0.03';
 }
 
 use strict;
@@ -16,12 +16,13 @@ use Params::Validate qw(:all);
 sub new {
     my $class = shift;
     my $p = validate(@_, {
-        blocking   => { type => BOOLEAN, default => 1 },
+        blocking      => { type => BOOLEAN, default => 1 },
         zkh           => { isa => 'Net::ZooKeeper' },
         lock_prefix   => { type => SCALAR, regex => qr{^/.+}o, default => '/lock' },
         lock_name     => { type => SCALAR, regex => qr{^[^/]+$}o },
         create_prefix => { type => BOOLEAN, default => 1 },
         watch_timeout => { type => SCALAR, regex => qr/^\d+$/o, default => 86400 * 1000 },
+        data          => { type => SCALAR, default => 0 },
     });
     $p->{lock_prefix} =~ s{/$}{};
 
@@ -36,6 +37,12 @@ sub new {
 }
 
 
+sub lock_path {
+    my $self = shift;
+    return $self->{lock_path};
+}
+
+
 sub unlock {
     my $self = shift;
     $self->{zkh}->delete($self->{lock_path}) if ($self->{lock_path});
@@ -73,7 +80,7 @@ sub _lock {
     }
 
     my $lock_tmpl = $lock_prefix . "/" . $lock_name . "-";
-    my $lock_path = $zkh->create($lock_tmpl, '0',
+    my $lock_path = $zkh->create($lock_tmpl, $self->{data},
         flags => (ZOO_EPHEMERAL | ZOO_SEQUENCE),
         acl   => ZOO_OPEN_ACL_UNSAFE) or
     die "unable to create sequence znode $lock_tmpl: " . $zkh->get_error . "\n";
@@ -143,6 +150,7 @@ sub DESTROY {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -151,7 +159,7 @@ Net::ZooKeeper::Lock - distributed locks via ZooKeeper
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -159,7 +167,7 @@ version 0.02
 
   # take a lock
   my $lock = Net::ZooKeeper::Lock->new({
-      zkh => Net::ZooKeeper->new(host => 'localhost:2181'),
+      zkh => Net::ZooKeeper->new('localhost:2181'),
       lock_name   => 'bar',
   });
 
@@ -210,8 +218,20 @@ You can create this prefix znode once in your code. Or you can use C<create_pref
 
 Default is 1.
 
+=item data
+
+Data to be stored in lock znode.
+
+It may be useful to store the hostname and pid of the process, that created the lock.
+
+Default is '0'.
+
 =back
 
+=item lock_path
+
+Returns the path of lock znode.
+
 =item unlock
 
 Releases getted lock. This method calls in destructor, so your lock releases when you go out of C<$lock> scope or when you call C<undef($lock)>.
@@ -232,16 +252,19 @@ L<Net::ZooKeeper>
 
 L<http://zookeeper.apache.org/doc/trunk/recipes.html#sc_recipes_Locks>
 
+=head1 ACKNOWLEDGEMENTS
+
+Oleg Komarov
+
 =head1 AUTHOR
 
 Yury Zavarin <yury.zavarin@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Yury Zavarin.
+This software is copyright (c) 2012 by Yury Zavarin.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
